@@ -41,7 +41,7 @@ class ChartMixin(ABC):
         color = color.lstrip("#")
         rgb = [int(color[i : i + 2], 16) for i in [0, 2, 4]]
 
-        return "rgba({},{},{}, 0.4)".format(*map(lambda x: rgb))
+        return "rgba({},{},{},0.4)".format(*map(lambda x: x, rgb))
 
 
 class BarChart(ChartMixin):
