@@ -21,6 +21,8 @@ class BaseChartView(ABC):
 
     def generate_options(self):
         options = {
+            "responsive": True,
+            "maintainAspectRatio": self.aspectRatio,
             "legend": {"display": self.legend},
             "title": {
                 "display": True if self.title is not None else False,
@@ -42,7 +44,7 @@ class BaseChartView(ABC):
         color = color_hex.lstrip("#")
         rgb = [int(color[i : i + 2], 16) for i in [0, 2, 4]]
 
-        return "rgba({},{},{}, 0.4)".format(*map(lambda x: rgb))
+        return "rgba({},{},{},0.4)".format(*map(lambda x: x, rgb))
 
     def get_context_data(self, **kwargs):
         context = super().get_context_data(**kwargs)
